@@ -29,18 +29,18 @@ var _ = Describe("generating source", func() {
 			Expect(len(results) == 1).To(BeTrue())
 		})
 
-		It("should produce a container config with no exclusions", func() {
+		It("should produce a container config", func() {
 			test.Expect(results[0]).ToEqual(`# container logs
 		  <source>
 			@type tail
 			@id container-input
 			path "/var/log/containers/*.log"
+			exclude_path ["/var/log/containers/fluentd-*_openshift-logging_*.log", "/var/log/containers/elasticsearch-*_openshift-logging_*.log", "/var/log/containers/kibana-*_openshift-logging_*.log"]
 			pos_file "/var/log/es-containers.log.pos"
 			refresh_interval 5
 			rotate_wait 5
 			tag kubernetes.*
 			read_from_head "true"
-			exclude_path []
 			@label @CONCAT
 			<parse>
 			  @type multi_format
@@ -185,18 +185,18 @@ var _ = Describe("generating source", func() {
 
 		Context("for container inputs", func() {
 
-			It("should produce a config with no exclusions", func() {
+			It("should produce a config", func() {
 				test.Expect(results[1]).ToEqual(`# container logs
 			  <source>
 				@type tail
 				@id container-input
 				path "/var/log/containers/*.log"
+				exclude_path ["/var/log/containers/fluentd-*_openshift-logging_*.log", "/var/log/containers/elasticsearch-*_openshift-logging_*.log", "/var/log/containers/kibana-*_openshift-logging_*.log"]
 				pos_file "/var/log/es-containers.log.pos"
 				refresh_interval 5
 				rotate_wait 5
 				tag kubernetes.*
 				read_from_head "true"
-				exclude_path []
 				@label @CONCAT
 				<parse>
 				  @type multi_format
