@@ -34,8 +34,9 @@ var secretCertificates = map[string]map[string]string{
 		"cert": "system.logging.kibana.crt",
 	},
 	"kibana-proxy": map[string]string{
-		"server-key":  "kibana-internal.key",
-		"server-cert": "kibana-internal.crt",
+		"server-key":     "kibana-internal.key",
+		"server-cert":    "kibana-internal.crt",
+		"session-secret": "kibana-session-secret",
 	},
 	"curator": map[string]string{
 		"ca":       "ca.crt",
@@ -49,14 +50,6 @@ var secretCertificates = map[string]map[string]string{
 		"ca-bundle.crt": "ca.crt",
 		"tls.key":       "system.logging.fluentd.key",
 		"tls.crt":       "system.logging.fluentd.crt",
-		/*legacy to be removed in future
-		"app-ca":     "ca.crt",
-		"app-key":    "system.logging.fluentd.key",
-		"app-cert":   "system.logging.fluentd.crt",
-		"infra-ca":   "ca.crt",
-		"infra-key":  "system.logging.fluentd.key",
-		"infra-cert": "system.logging.fluentd.crt",
-		*/
 	},
 }
 
